function [llr,ls,ld] = c_compLLRd(da, D, para)
% c_compLLRd  find log like ratio value by estimating dist (from D) at da
%
% [llr,ls,ld] = c_compLLRd(da, D, para)
%
% da -  n x m appearance distance values 
% D  -  n x 4 distribution parameters 
%       each row: [same_mean same_gamma diff_mean diff_gamma]
%
% para.std_lim : limit da to be no more then std_lim standard distributions
% away from both distributions...
%
% para.llr_lim : limits on the llr score for each patch - since our model is
% sometimes off, especially at the extremes, we want to limit the amount of
% damage a single bad estimate can have on the score.
  
  sm = D(:,1); % same_mean
  sv = D(:,2); % same_gamma
  dm = D(:,3); % diff_mean
  dv = D(:,4); % diff_gamma
  
  % the model is not great at at the extremes. If std_lim para is
  % set, we limit da to be no more then std_lim standard deviations 
  % from both models...
  if(para.std_lim)
    % compute standard deviation based on mean, gamma: 
    %   var = mean^2/gamma 
    ss = sqrt(sm.^2./sv); 
    ds = sqrt(dm.^2./dv);
    
    limits = [dm-modparam.std_lim*ds sm+modparam.std_lim*ss];
    dalim = min(max(da, repmat(limits(:,1), [1 size(X,2)])), ...
	       repmat(limits(:,2), [1 size(X,2)]));
  else
    dalim=da;
  end
  
  ls = log(gampdf(dalim, repmat(sv, [1, size(da,2)]), ...
		 repmat(sm./sv, [1, size(da,2)])));
  ld = log(gampdf(dalim, repmat(dv, [1, size(da,2)]), ...
		 repmat(dm./dv, [1, size(da,2)])));
  
  llr=ls-ld;

  % fix limits 
  llr = max(para.llr_lim(1), min(para.llr_lim(2), llr));
  
