function [data, name] = getIm(fio, seqnum, ind, useCache);
% getIm(fio)  the main get function of fio (all others call this)
%
% [data, name] = getIm(fio, seqnum/pname(o), ind(o), useCache(o))
% read image/data from file, which is element ind of subsequence seqnum.
% if only fio is given, grabs current element of current subsequence
% if seqnum=-1, grabs element ind from current subsequence
% if a partial name (a string) is given as the 2nd parameter, finds the 
%   first element which begins with pname or with [prefix pname] (ind is ignored)
% if ind = -1, the current index is used 
% to cache the result of the read (usful for complicated io functions)
%  pass in  useCache=3 (see help setCache). This is ANDed with the cache
%  settings of fio (we dont cache by default, as its not useful for most datatypes).
  
  name = '';
  if(nargin<3)
    ind = seqnum;
    seqnum = -1;
  end
  if(exist('seqnum')~=1 | seqnum<0)
    seqnum=fio.curseq;
  elseif(isa(seqnum,'char'))
    if(length(fio.prefix) & strncmp(seqnum,fio.prefix, length(fio.prefix)))
      st = seqnum;
    else
      st = [fio.prefix seqnum];
    end
    n = findSubStr(st, fio.dirlist);
    if(n==0)
      warning(['No matches found to ' st]);
      data = 0;
      return;
    else
      if(length(n)>1)
	warning(['Multiple matches found to ' st '. Returning first only.']);
      end
      seqnum = 0;
      ind = n(1);
    end
  end
  
  if(seqnum==0)
    if(exist('ind')~=1 | ind<1)
      ind = fio.curInd;
    end
  else
    try
      if(exist('ind')~=1 | ind<1)
	ind = fio.subseqs{seqnum}(fio.subseqind(seqnum));
      else
	ind = fio.subseqs{seqnum}(ind);
      end
    catch
      warning('subseqind out of bounds');
      data = 0;
      return
    end
  end
  
  if(exist('useCache')~=1)
    useCache = 0;
  end
  
  if(ind>0 & ind<=length(fio.dirlist)) 
    if(bitand(useCache,1) & checkCache(fio, 'fileRead', fio.dirlist{ind}))
      data = readCache(fio, 'fileRead', fio.dirlist{ind}); 
    else
      data = fileRead(fio.dirpath,fio.dirlist{ind}, fio.params);
      if( bitand(useCache,2))
	writeCache(fio, data, 'fileRead', fio.dirlist{ind});
      end
    end
    name = fio.dirlist{ind};
  else
    warning('frame index out of range.');
    data = 0;
  end
