function v = subsref(fio, S)
% subsref(fio)  subscript references overloaded for frameIo class
%
% v = subsref(fio, S) 
%   fio{i} returns ith image/data of the current subsequence
%   fio(i) returns ith image/data 
%   fio('str') returns the first image/data whos name begins with str or [fio.prefix str]
%   fio.im and fio.imind return current image and index of current image
%   fio.dirpath and fio.cacheDir return current file directory and cache direcectory
%   fio.params returns the params structure
% also note that you can use multiple subrefs. that is, if fio(1) is an image,
% you can call fio(1,15,1:10) to return the first 10 pixels of line 15 of image 1.
% (for {} calls use fio{1}(15,1:10))
% however, be cautious: fio(1) needs to be read in from disk, so this is a pretty expensive
% call. 
% Also, note that all of these calls return a COPY, not the original. That is, you 
% can not set it using this syntax (this is pretty obvious if you think about what  
% fio(1)(15,1) = 1 would require.)

  switch S(1).type(1)
   case '{'
      v = getIm(fio, -1, S(1).subs{1}(1));
   case '('
    if(isa(S(1).subs{1},'char'))
      v = getIm(fio, S(1).subs{1});
    else
      v = getIm(fio, 0, S(1).subs{1}(1));
    end
    %call subsref recursivly for multi dimensional calls
    if(length(S(1).subs)>1)
      S2.type = S(1).type;
      S2.subs = {S(1).subs{2:end}};
      v = subsref(v,S2);
    end
   case '.'
    if(strcmp(S(1).subs,'im'))
      v = getIm(fio);
    elseif(strcmp(S(1).subs,'name'))
      if(fio.curInd>0)
	v = getName(fio);
      else
	v = getName(fio, -1, 1);
      end
    elseif(strcmp(S(1).subs,'fullname'))
      if(fio.curInd>0)
	[junk, v] = getName(fio);
      else
	[junk, v] = getName(fio, -1, 1);
      end
    elseif(strcmp(S(1).subs,'imind'))
      if(fio.curseq==0)
	curInd = fio.curInd;
	realCurInd = curInd;
      else
	curInd = fio.subseqind(fio.curseq);
	try
	  realCurInd = fio.subseqs{fio.curseq}(curInd);
	catch
	  realCurInd = 0;
	end
      end
      v = [fio.curseq curInd realCurInd];
    elseif(strcmp(S(1).subs,'dirpath') | strcmp(S(1).subs,'path'))
      v = fio.dirpath;
    elseif (strcmp(S(1).subs,'cacheDir'))
      v = fio.cacheDir;
    elseif (strcmp(S(1).subs,'params'))
      v = fio.params;
    else
      error(['fio.' S(1).subs ' not defined.']);;
    end
  end

  % finally call subsref recursivelyif needed.
  if(length(S)>1)
    v = subsref(v,S(2:end));
  end

  
