% Common Useful Matlab and Image Processing Functions
% Many functions to make working with Matlab easier (at least for me -ADF)
%
% Look through the directories to find what you are looking for...
%
%
% --- Automatic Contents.m Creation ---
% Created on 13-Oct-2005 00:42:18 by ferencz using makeContents 
% 
%  
%   Dir: vid/common/@frameIo
%  
%    getCacheDir  returns cache directory for fio object
%    addSpec  adds or alters spceial data elements 
%    addSubSeq   add a subsequence definition to this frameIo object
%    frameIo  class for reading image or other file sequences and caching computed data
%    getIm(fio)  the main get function of fio (all others call this)
%    get file name and full path of fio element 
%    length(fio) the length of the current subsequence
%    [fio, im, name] = nextIm(fio)
%    setCache  sets caching behavior
%    setParams(fio)   set elements of fio params struct (params is passed to IO func)
%   [fio, im, name] = setIm(fio, seqnum, ind)
%    subsref(fio)  subscript references overloaded for frameIo class
%     useCache  return 1 if we should use the cache
%  
%   Dir: vid/common/algo
%  
%   HUNGARIAN Solve the Assignment problem using the Hungarian method.
%  
%   Dir: vid/common/cache
%  
%    cacheWrapCheck  wraper for retreiving cached output of function (but does not call func)   
%    bool = cacheCheck(gfio, imName, func, varargin)
%    cacheName  make filename for cache item (dataName/dataType/fileType) combination
%    cacheWrap  wraper for caching output of function   
%    findCacheDir  given a path to the data, finds a good cache directory to use
%    checkCache   check if dataType/dataName is in cache
%    clearCache  clear the cache of all files that match 
%    lsCache  list cache contents
%    readCache  read cache item
%    writeCache  write a cache file 
%  
%   Dir: vid/common/dataanal
%  
%    compute first 2 moments for each column for the 2-D hist h as returned by histc2
%    create K-dim histogram and compute moments for each bin
%    create 2-D histogram image 
%    sumdim   sum multiple dimensions in one go 
%  
%   Dir: vid/common/fileIo
%  
%    fileRead   read all sorts of data
%    fileWrite   write all sorts of data
%   
%  
%   Dir: vid/common/filter
%  
%     outim = blur(im, filt) 
%    reduce   blur and subsample by a factor of 2
%    halfWaveRectChannels   given an image, split the channels into positive and negative components
%    make bank of directional gaussian derivative filters
%    make_filterbank_12   makes a predefined filter bank set...
%    oddFilterPyr  
%    pyramid   make image pyramid out of image
%     make direction gaussian derivative filter
%    
%     Dir: vid/common/filter/steerable
%    
%     % run the steerable filter
%      showFiltered(fim,th, fig, mask)  
%     [G2,H2] = steer(theta,basis)
%     foo
%      fpyr = steerFilterPyr(pyr)
%      [theta,strength,phase,energy] = steer_max(basis)
%      defines a set of seperable quadrature pair 
%  
%   Dir: vid/common/frames
%  
%    varargout = cacheWrap(gfio, imName, func, varargin)
%    this is just a wrapper for @frameIo/readCache
%   showims(ims, start,n,skip,fignum,imnums)
%    this is just a wrapper for @frameIo/writeCache
%  
%   Dir: vid/common/gabor
%  
%    CONV2B Two-dimensional convolution with border handling
%    GABORCONVOLVE - function for convolving image with log-Gabor filters
%    GABSPLEV obtains a whole level of the pyramidal Gabor decomposition.
%    GABSPPYR Gabor spatial pyramidal decomposition
%    INVGAB Inverse Gabor transform (image reconstruction)
%    mask definitions for Gabor pyramid decomposition
%  
%   Dir: vid/common/image
%  
%    create an from a sequence by tiling the frames
%    idtype = imDataType(prefs [, param1, param2, ... ])
%    make image data structure
%    imFileRead  read an image of various formats, and rotate/rescale it
%    imagegr(im) draws the image with trueColor (ignoring the colormap). 
%    local display functions for various image types
%    rect format [ymin xmin; ymax xmax]; 
%    zero (or copy some fixed value v into) the border of an image...
%  
%   Dir: vid/common/imagegui
%  
%    imagexy  calls imagegr; axis image, xy
%    ptlist(j,:) format = [fnum y x]
%    labelInd = getLabelIndForFrames(fio, labelNum, frameInd)
%  
%   Dir: vid/common/langext
%  
%    array2cell   convert an array/martix of stuff to a cell array of stuff 
%    findSubStr   find first string in cell str c that contains substring s
%    assert   throw an error if a statement is false
%    dplus  matrix addition similar to +, but handles some non-equal matrix sizes
%    dtimes  array multiply similar to .*, but handles some non-equal matrix sizes
%    makeContents   recursively create Contents.m files in source directory tree
%    makeParams   utility for making paramter structures where defaults can be overwritten 
%    make a sparse if it has less than p percent nonzeros 
%    mapfunc  map a function onto a array or cell array
%    setStructDefaults  set values in S only if the fields don't already exist
%    mergeStructs  merge structrures into 1 struct
%    position matrix A insize larger matrix of size S
%    position matrix A insize larger matrix of size S
%    roundto   rounds to nearest value with given fractional part
%    size1  like matlab's size, but allows you to specify multiple dims 
%    bound   cap the values of b to the range lims 
%    structArray2Struct  convert an array of structures to a single struct with arrays
%  
%   Dir: vid/common/matfiles
%  
%  
%   Dir: vid/common/metrics
%  
%  
%   Dir: vid/common/pnm
%  
%   FASTPGMWRITE Write a PGM (portable graymap) file to disk.
%    README file for the Portable pixelmap utilities.
%   CMSORT   Sort color map.
%   IM2INDD  Convert image to indexed image (direct conversion).
%   IM2IND   Convert image to indexed image with unique colors in map.
%   IM2INDR  Convert image to indexed image with unique colors in map.
%   IM2INDS  Convert image to indexed image with unique colors in map.
%   PBMREAD  Read a PBM (portable bitmap) file from disk.
%   PBMWRITE Write a PBM (portable bitmap) file to disk.
%   PGMREAD  Read a PFM (portable floatmap - mobileye convensions) file from disk.
%   PGMREAD  Read a PGM (portable graymap) file from disk.
%   PGMWRITE Write a PGM (portable graymap) file to disk.
%   PNMDEMO Demonstration of portable bitmap utilities.
%   PNMGETI Get integers from an ascii encoded PBM/PGM/PPM file.
%   PNMMAGIC Find and identify magic number in PBM/PGM/PPM file.
%   PNMTEST Test program for the PNM Toolbox.
%   PPMREAD  Read a PPM (portable pixmap) file from disk.
%   PPMWRITE Write a PPM (portable pixmap) file to disk.
%   XBMREAD  Read a XBM (X bitmap) file from disk.
%   XBMWRITE Write a XBM (X bitmap) file to disk.
%  
%   Dir: vid/common/random
%  
%  
%   Dir: vid/common/sparse
%  
%  
%   Dir: vid/common/stat
%  
%    nthSmallest   order statistic: return the 100*n percentile value 
%    gaussDeriv   evaluate the Nth derivative of a normal distribution 
%    gaussian   evaluate the normal distribution with mean, sigma at x
%    joint2cond   convert joint distribution matrix to the conditional distribution matrix
%    sampleEntropy       Estimate entropy of distribution from a sample.
%    sigmoid   evaluates the sigmoid function at x
%    vasicekExact       Estimate entropy of distribution from a sample.
%   DISTCHCK Checks the argument list for the probability functions.
%   GAMPDF Gamma probability density function.
%    LARS Least Angle Regression 
%  
%   Dir: vid/common/uitools
%  
%    expParamSetup  set up export parameters ExpParam (script)
%    addLegend   add a legend item to the current plot for the given dawing object 
%    ctext  color text annotation
%    letter2color  convert a letter to an rgb color value
%    makeHTMLPage   make an HTML page with all the given images 
%    makeMovie   make a movie from a sequence of images
%    mdisp   display multiple variables (strings, numbers, objects) 
%    mplot   plot with larger marker and line (uses ExpParam) 
%    mprint   save current matlab plot to .jpg and/or .fig (uses ExpParam)
%    [figp] = parseFignum(fignum, minnum)
%    plotLabeled   plot points with labels
%    subplot1  like subplot, but figures out how to arange the subplots in i and j
%    toColor  convert a letter or number to an rgb color value
%  
%   Dir: vid/common/vistool
%  
%    localmax  make local maximum image in N-Dim image
%    pickFilteredPts   subsample edges for interest points
%    nonMaxSupressForSteer  non max supression for steer filtered images...
%    [F1,F2]=quadpair(sig,lam,th,N);
%    xcorr2   normalized cross correlation similar to normxcorr2
