function [cname, dirname] = cacheName(fio, dataName, dataType, permanent, fileType) 
% cacheName  make filename for cache item (dataName/dataType/fileType) combination
% [cname, dirname] = cacheName(cacheName/fio, dataName, dataType(o), permanent(o), fileType)
% non-permanent cache entrees have the format 
%   cachepath/.cache/dataType_dataName.fileType
% permanent entrees work the same way but are in directory ../.perm/..
%  and can not be deleted with clearCache.  These are used for items
%  that can not be easily regenerated, like user input. 
% fileType defaults to mat file if not given. 
  
  if(exist('dataType')~=1)
    dataType = '';
  elseif(isnumeric(dataName))
    dataName = num2str(dataName);
  end
  if(exist('permanent')~=1)
    permanent=0;
  end
  if(exist('fileType')~=1)
    fileType = 'mat';
  end
  
  if(isa(fio, 'frameIo'))
    cachepath = getCacheDir(fio);
  else
    if(any(fio))
      cachepath = fio;
    else
      global gCacheBase
      if(exist('gCacheBase')==1 & any(gCacheBase))
	cachepath = gCacheBase;
      else
	cachepath = '.';
      end
    end
  end 
  
  if(permanent)
    dirname = [cachepath '/.perm'];
  else
    dirname = [cachepath '/.cache'];
  end 
 
  cname = [dirname '/' dataType '_' dataName '.' fileType]; 
  