function outim = blur(im, filt)
%  outim = blur(im, filt) 
%  im       input image
%  filt     (opt, default=[1 4 6 4 1]) filter to use for blurring
%           filt may also be a sigma value, where the filter is a gaussian with 
%           that sigma. 
  
  if(nargin<2)
    filt = [1 4 6 4 1];
  else
    if(length(filt)<2) % create a gaussian up to 9-tap filter with given sigma
      x=(-4.55:0.1:4.55);
      y = gaussian(x, 0, filt);
      filt = zeros(1,9);
      for i=(-4:4)
	filt(i+5)=mean(y(x>=(i-0.5) & x<(i+0.5)));
      end
      k=max(find(filt(1:4)<0.001));
      if(length(k)>0)
	filt = filt(1+k:9-k);
      end
      filt = filt/(sum(filt));
    end
  end
  redfilt = filt'*filt;
  redfilt = redfilt/sum(sum(redfilt));
  
  for i=1:size(im,3)
    outim(:,:,i) = conv2(im(:,:,i),redfilt,'same');
  end

  
