function [fb, th]  = makeFilterBank(n, sigma, der, ext, s)
% make bank of directional gaussian derivative filters
%
% [fb, th] = makeFilterBank(n, sigma, der, ext, s)
% n     1x1 = number of directions from 0 to 180 degrees
% sigma 1x2 = major/minor axis sigma of gaussian
% der   1x2 = which derivate in each direction (0, 1, 2...)
% ext   1x2 = extent of filter in sigma units for each axis
% s     1x2 = size of final image (default = max size of any of them)
%
% output
%  fb s(1) x s(2) x n image 
%  th 1xn vector of directions in degrees 
% example
%  [fb, th] = makeFilterBank(6, [4 1], [0 1], [2 4], [11 11]);
  
  if(nargin<3)
    der = [0 1];
  end
  
  if(nargin<2 | length(sigma)<2)
    sigma = [4 1];
  end
  
  if(nargin<4)
    ext = [1.5 3]; 
  end
  
  r = linspace(0, 180, n+1);
  r = r(1:end-1);
  
  ss = [0 0];
  for i=1:n
    f{i} = makeGFilter(sigma, der, ext, r(i));
    ss = max(ss, size(f{i}));
  end
  
  if(nargin<5)
    s = ss;
  end
  fb = zeros(s(1), s(2));
  c = ceil(s/2);
  for i=1:n
    ss = size(f{i});
    sm = min(ss, s); d = max(0, ss-sm);
    ir = (1:sm(1))-ceil(sm(1)/2);
    jr = (1:sm(2))-ceil(sm(2)/2);
    fb(c(1)+ir,c(2)+jr,i) = ...
	f{i}(1+floor(d(1)/2):end-ceil(d(1)/2),...
	     1+floor(d(2)/2):end-ceil(d(2)/2));
  end
  
  th = r;
