function f = makeGFilter(sigma, der, ext, rotDeg)
%  make direction gaussian derivative filter
%
%  f = makeGFilter(sigma, der, ext, rotDeg)
%
%  sigma  1x2 = [majorAxis minorAxis]
%  der    1x2 = derivative (0, 1, 2...) of gausian to use for each axis  
%  ext    1x2 = extent of filter in sigma units for each axis
%  rotDeg 1x1 = rotate final filter ccw by this amount in degrees 
  
  if(nargin<4 | length(rotDeg)<1)
    rotDeg = 0;
  end

  if(nargin<3 | length(ext)<2)
    ext = [1.5 3];
  end
  
  if(nargin<2 | length(der)<2)
    der = [0 1];
  end  
  
  yr = floor(-ext(1)*sigma(1)):ceil(ext(1)*sigma(1));
  xr = floor(-ext(2)*sigma(2)):ceil(ext(2)*sigma(2));
  gy = makerow(gaussDeriv(yr, 0, sigma(1), der(1)));
  gx = makerow(gaussDeriv(xr, 0, sigma(2), der(2)));
  
  f = gy'*gx;
  
  if(rotDeg~=0)
    f = imrotate(f, rotDeg, 'bicubic');
  end

  % finally make sure that the filter sum is 0
  % by multiplying the positive and negative components of the filter by
  % some weights.
  s = sum(f(:));
  p = find(f>0);
  f(p)= f(p)*(1-s/(2*sum(f(p))));
  p = find(f<0);
  f(p)= f(p)*(1-s/(2*sum(f(p))));
  
  
