
function [edgemap] = steerable_edges(img,scale,threshold)


%% run the steerable filter
[basis] = steerable_gauss(img,scale);
[theta,strength,phase,energy] = steer_max(basis);
mag = strength;

%% now fit a parabola to each point
sint = sin(theta);
cost = cos(theta);
beta = 2*sint.^2 .* cost.^2 + 1;

distx = [-1 0 1];
disty = [-1 0 1]';
avex  = [1 1 1];
avey  = [1 1 1]';

deltainv = 1 ./ (6 * (3*beta-2));
slope = -conv2(conv2(mag,-distx,'same'),avey,'same').*sint + ...
        conv2(conv2(mag,-disty,'same'),avex,'same').*cost;
curve = conv2(conv2(mag,-distx.^2,'same'),avey,'same') .* sint.^2 + ...
         conv2(conv2(mag,-disty.^2,'same'),avex,'same') .* cost.^2 - ...
          2*conv2(conv2(mag,-distx,'same'),-disty,'same') .* sint .* cost;
average = conv2(conv2(mag,avex,'same'),avey,'same');
grad2average = conv2(conv2(mag.^2,avex,'same'),avey,'same');
a = deltainv .* ((3 * curve) - (2 * average));
b = slope / 6;
c = deltainv .* ((2 * beta .* average) - 2 * curve);
dist = 0.5 * b ./ a;
height = -.25 * b.^2 ./ a + c;
fit2norm = 6*(beta .* (a.^2) + (b.^2)) + 9*(c.^2) + 12*(a.*c);
fit_err = 1 - (fit2norm ./ grad2average);

%% choose a threshold based on the histogram
sorted = sort(mag(:));
thresh = sorted(round(length(sorted)*threshold));
fitthresh = 0.001;

%% compute the edgemap
edgemap = (abs(dist) < sqrt(2)) .* (mag > thresh) .* (fit_err < fitthresh); 

