function M = fmontage(F, s, flags, varargin)
% create an from a sequence by tiling the frames
%
% M = fmontage(F, s, flags, varargin)
% 
% F frames MxNxK array of K frames 
% s layout [num_horiz num_vert] ([] for automatic)
% flags = {'t', 'm'}
%  t = transpose order (go column-wise)
%  m = add margin between images 
%      optional argument [num_pix value]
%
%  ex: imagesc(fmontage(F,[3 4], 'tm', 2));  
  
  if(~exist('s') | length(s)~=2)
    s=[0 0];
  end
  
  margin = 0;
  t=0;
  varin = 1;
  if(exist('flags')==1)
    for i=1:length(flags)
      switch(flags(i))
       case 't'
	t=1;
       case 'm'
	if(length(varargin)>=varin)
	  margin=varargin{varin};
	else
	  margin = 1;
	end
	varin=varin+1;
      end
    end
  end

  if(length(margin)==1)
    margin(2) = 0;
  end


  if(iscell(F) | isa(F, 'frameIo'))
    error('Not yet implemented');
  elseif(isreal(F))
    fs = size(F);
    
    if(length(fs)>2)
      n = fs(end);
    else
      mim = F;
      return
    end
    s = setS(s,n);
    
    if(length(fs)==4)
      M = zeros((fs(2)+margin(1))*s(2)-margin(1), ...
		(fs(1)+margin(1))*s(1)-margin(1), fs(3))+margin(2);
      for i=1:s(1)
	for j=1:s(2)
	  if(t)
	    if(fs(4)>=(j-1)*s(2)+i)
	      I = F(:,:,:,(j-1)*s(2)+i);
	    else
	      I = zeros(fs(1:2));
	    end
	  else
	    if(fs(4)>=(i-1)*s(2)+j)
	      I = F(:,:,:,(i-1)*s(2)+j);
	    else
	      I = zeros(fs(1:2));
	    end
	  end
	  M((j-1)*(fs(2)+margin(1))+(1:fs(2)),...
	    (i-1)*(fs(1)+margin(1))+(1:fs(1)),:) = I;
	end
      end
    elseif(length(fs)==3)
       M = zeros((fs(1)+margin(1))*s(1)-margin(1), ...
		(fs(2)+margin(1))*s(2)-margin(1))+margin(2);
      for i=1:s(1)
	for j=1:s(2)
	  if(t)  
	    if(fs(3)>=(j-1)*s(2)+i)
	      I = F(:,:,(j-1)*s(2)+i);
	    else
	      I = zeros(fs(1:2));
	    end
	  else
	    if(fs(3)>=(i-1)*s(2)+j)
	      I = F(:,:,(i-1)*s(2)+j);
	    else
	      I = zeros(fs(1:2));
	    end
	  end
	  M((i-1)*(fs(1)+margin(1))+(1:fs(1)),(j-1)*(fs(2)+margin(1))+(1:fs(2))) = I;
	end
      end
    end
  end
  
  
  
function s = setS(s,n)
  if(prod(s))
    return;
  elseif(any(s))
    w = ceil(n/sum(s));
    s = [w w].*(s(2:-1:1)>0)+s;
  else % s=[0 0]
    w1 = ceil(sqrt(n));
    s  = [ceil(n/w1) w1]; 
  end
    
    
  
  
  