function idtype = imDataType(prefs, varargin)
% idtype = imDataType(prefs [, param1, param2, ... ])
% 
% prefs can have any combination of:
%   g  use grayscale image (even if imput was color)
%   p  for each field, create pyramid with 4 levels
%   f  create steer filter image (fim)
%   t  create tefim from fim (turns f on)
%   c  create oriented filter channels (parameter=# of channels)
%   C  same as c but creates unsigned output
%   b  use filter bank (parameter = mat file name)
%   h  same as c but creates half wave rectified filters (2X # of channels)
%   s  use steerable filters for cahnnels
%   r  find region of interest (only if a bgim is available)
%   e  create edge mask (parameter=threshold)
%   w  frame width (number of pixels at edge set to 0 in fim) (parameter)    
%         (default=5)
%   t  make texton image (find textons for this image, assumes FB23.mat)
%        (parmeter=number of centers);
%   u  make universal texton image (assume existance of TextonCenters.mat)   
%
%   parameters, where indicated) are placed in varargin in same
%   order as their apperance in prefs
  
  idtype = struct('use_one_ch', 0, 'pyr', 0, 'frameWidth', 5, 'find_roi', 0, ...
		  'filter_im', 0, 'tef_im', 0, 'filter_channels', 0, ...
		  'edge_mask', 0, 'use_steer_channels', 0, ...
		  'abs_value_channels', 1, 'texton_im', 0, ...
		  'FB', 0, 'txtCenters', 0, 'useFB', [], ...
		  'fbname', 'def');
  
  n=1;
  for c=prefs
    switch c
     case 'g'
      idtype.use_one_ch = 1;
     case 'p'
      idtype.pyr = 1;
     case 'r'
      idtype.find_roi = 1;
     case 'f'
      idtype.filter_im = 1;
     case 't'
      idtype.tef_im = 1;
     case 'c'
      idtype.filter_channels = varargin{n};
      idtype.abs_value_channels = 0;
      n=n+1;
     case 'C'
      idtype.filter_channels = varargin{n};
      n=n+1;
     case 'b'
      tmp = load(varargin{n});
      idtype.useFB = tmp.FB;
      idtype.fbname = varargin{n};
      n=n+1;
     case 'h'
      idtype.filter_channels = varargin{n};
      idtype.abs_value_channels = 2;
      n=n+1; 
     case 's'
      idtype.use_steer_channels = 1;
     case 'e'
      idtype.edge_mask = varargin{n};
      n=n+1;
     case 'p'
      idtype.pyr = 1;
     case 'w'
      idtype.frameWidth = varargin{n};
      n=n+1;
     case 't'
      idtype.texton_im = varargin{n};
      load FB23.mat;
      idtype.FB = FB;
     case 'u'
      idtype.texton_im = 1;
      load FB23;
      idtype.FB = FB;
      load TextonCenters;
      idtype.txtCenters = txtCenters;
    end
  end
  
  

  
  