function [im,comments] = imFileRead(name, params) 
% imFileRead  read an image of various formats, and rotate/rescale it
%
% im = imFileRead(name, params(o)) 
% uses 
%   parmas.rot which flips image up-down mod(rot,4) times and 
%     then rotates image clockwise rot*90 degrees (so 6 flips left-right)
%   parmas.rescale which must be an integer and enlarges or 
%     reduces by (2^rescale)
  
  if(exist('params')~=1)
    params.rescale = 0;
    params.rot=0;
  end
  comments = {};
  
  try
    fmt = name(end-2:end);
    if(strcmp(fmt,'pgm')) % | strcmp(fmt,'pnm') | strcmp(fmt,'ppm'))
      [im, comments] = pgmread1(name);
    elseif (strcmp(fmt,'mat'))
      S = struct2cell(load(name));
      im = S{1};
    else
      im = double(imread(name));
    end
  catch
    warning(['imFileRead: no such file: ' name]);
    im = 0;
    return
  end
  
  channels = size(im,3);
  if(isfield(params, 'rescale') & params.rescale)
    if(params.rescale>0)
      for i=1:1:params.rescale
	clear tim;
	for c=1:channels
	  tim(:,:,c)=enlarge(im(:,:,c));
	end
	im = tim;
      end
    else
      for i=-1:-1:params.rescale
	clear tim;
	for c=1:channels
	  tim(:,:,c)=reduce(im(:,:,c));
	end
	im = tim;
      end      
    end
    clear tim;
  end
  
  if(isfield(params, 'rot') & params.rot)
    if(params.rot>3)
      for c=1:channels
	im(:,:,c) = flipud(im(:,:,c)); 
      end
    end
    if(mod(params.rot,4)>0)
      for c=1:channels
	tim(:,:,c) = rot90(im(:,:,c),params.rot);
      end
      im = tim;
      clear tim;
    end
  end

  if(max(im(:))>1)
    im = im/255;
  end
  
  im = double(im);

