function imd = makeImDataStruct(im, name, bgim, fim, fgbim, idtype, cachedir)
% make image data structure
% imd = makeImDataStruct(im, name, bgim, fim, fgbim, idtype)
% last 4 inputs are are opt. use arg=0 to set arg to undefined.
% 
% imd = makeImDataStruct(fio,idx,idtype);
% where 
% idx can be opt or 0
% idtype is opt.
  
  if(isa(im,'frameIo'))
    if(exist('bgim')==1)
      idtype = bgim;
    end
    fio = im;
    idx=0;
    if(exist('name')==1)
      idx = name;
    end
    [im, name]= getIm(fio, -1, idx);
    
    bgim = getSpec(fio,'bgim');
    fbgim = getSpec(fio,'fbgim');
  else
    if(exist('cachedir'))
      fio = cachedir;
    else
      fio=0;
    end
    if(exist('name')~=1)
      name = inputname(1);
    end
  end

  
  if(exist('idtype')~=1 | strcmp(class(idtype),'struct')==0)
    clear idtype;
    global idtype;
  end

  
  s = [size(im,1) size(im,2)];
  channels = size(im,3);
  
  if(idtype.use_one_ch==1)
    im = mean(im,3);
  end

  imd = struct('idtype',idtype,'name', name, 'size', s, 'channels', channels, ...
	       'im',im, 'fgmask', 0, 'center', 0, ...
	       'brect', 0, 'fim', 0, 'ffgmask', 0, 'edgeMask', 0, ...
	       'tefim', 0, 'fchannels', 0, 'chdir', 0, ...
	       'combineGH', 0, 'pts', 0, 'txtim', 0, 'txtCenters', 0);

  
  % working with the image
  if(idtype.pyr)
    imd.im = pyramid(im,4);
  end

  if(exist('bgim')==1 & any(bgim))
    imd.fgmask = cacheWrap(fio, name, @makefgmask, im, bgim, 0.2);
    if(idtype.find_roi)
      [imd.center, imd.brect] = findBoundRect(imd.fgmask);
    end
  end

  %results from cmputing steer filters
  if((idtype.filter_im | idtype.edge_mask | idtype.tef_im) & ...
     (exist('fim')~=1 | ~any(fim(:))))
    fim = clearEdges(cacheWrap(fio, name, @steerFilterPyr, imd.im),idtype.frameWidth);
  end

  if(idtype.filter_im)
    imd.fim = fim;
  end

  if(exist('fbgim')==1 & any(fbgim))
    imd.ffgmask = cacheWrap(fio, [name '_f'], @makefgmask, fim, fbgim, ...
			    [5 0.01 0.01], 1,1);
    if(idtype.edge_mask)
      imd.edgeMask = cacheWrap(fio, name, @nonMaxSuppress, fim(:,:,1), ...
			       fim(:,:,2) + fim(:,:,3), imd.ffgmask.* ...
			       (fim(:,:,2)+fim(:,:,3))>idtype.edge_mask); 
    end
  elseif(idtype.edge_mask)
    imd.edgeMask = cacheWrap(fio, name, @nonMaxSuppress, fim(:,:,1), ...
			     fim(:,:,2)+ fim(:,:,3), ...
			     (fim(:,:,2)+fim(:,:,3))> idtype.edge_mask, 4);
  end
    
  if(idtype.edge_mask)
    imd.pts = cacheWrap(fio, name, @pickFilteredPts, imd.edgeMask, 2, fim(:,:,1));
  end
  
  if(idtype.tef_im)
    imd.tefim = fim2tefim(fim);
  end    

  
  if(any(idtype.filter_channels))
    if(idtype.use_steer_channels)
      %results form computing directional filters
      [imd.fchannels, imd.chdir, imd.combineGH] =  ...
	  cacheWrap(fio, name, @steerChannels, ...
		    imd.im, idtype.filter_channels);
      imd.fchannels = clearEdges(imd.fchannels,idtype.frameWidth);
    else
      %results form computing directional filters
      [fch, imd.chdir, imd.combineGH] =  ...
	  cacheWrap(fio, [name '_' idtype.fbname], @oddFilterPyr, ...
		    imd.im, idtype.filter_channels, 0, idtype.useFB);
	fch = clearEdges(fch,idtype.frameWidth);
      if(idtype.abs_value_channels==1)
        imd.fchannels = abs(fch);
      elseif(idtype.abs_value_channels==2)
        imd.fchannels = cat(3, max(0, fch), max(0, -fch));
      else
        imd.fchannels = fch;
      end
    end
  end
  
  
  if(idtype.texton_im)
    if(idtype.texton_im==1)
      imd.txtim = cacheWrap(fio, name, @makeUTextonImage, im, idtype.FB, idtype.txtCenters);
    else
      [imd.txtim, imd.txtCenters] = cacheWrap(fio, name, @makeTextonImage, im, idtype.FB, idtype.txtCenters);
    end
  end
