function hlines = makeContents(rootdir, writeit)
% makeContents   recursively create Contents.m files in source directory tree
%
% hlines = makeContents(rootdir, writeit)
% 
% rootdir - directory name (e.g. common or common/stat)
% writeit - (o) actually write the file? 2 element vector: [root, recursive]
%               (def. [1 1])
%
% Given a directory name makeContents creates a Contents.m help file by recursively
% walking over a directory tree, and making an indented list of all functions found. 
% If writeit(2)==1, then the Contents.m files in the subdirectories are also written.
% 
% If a Contents.m file exists already in a directory, it is only modified if it has 
% the line:
%
% % --- Automatic Contents.m Creation ---
%
% and only the parts after this line are altered. 
% 
% Example: to recursively do this for your whole directory tree (if root directory is
% named matlab), without placing one in your root directory, do:
%
% cd ..
% makeContents('matlab', [0 1]);
% cd matlab
%
% Suggestion: it might be useful to create the root level Contents.m file
% so you can have it open in a buffer in Emacs.  This allows matlab to 
% auto complete (Alt-/) all the available matlab functions in your directory
% tree. 
  
  AutoString = '% --- Automatic Contents.m Creation ---';
  d = dir(rootdir);
  C = {};
  if(nargin<2)
    writeit=[1 1];
  elseif(length(writeit)==1)
    writeit = writeit([1 1]);
  end
  
  for i=1:length(d)
    % recurse in to the directories... 
    if(d(i).name(1)~='.' & d(i).isdir)
      C{end+1}.name =  d(i).name;
      C{end}.cont = makeContents(fullfile(rootdir, d(i).name), writeit(2));
    end  
  end
  
  contfile = fullfile(rootdir,'Contents.m');
  dc = dir(contfile);

  lines={};
  moved=0; 
  if(length(dc))
    writeit(1)=0;
    fid = fopen(contfile);
    while 1
      tline = fgetl(fid);
      if ~ischar(tline), break, end
      if(strcmp(tline,AutoString))
	writeit(1)=1;
	break;
      end
      lines{end+1}=tline;
    end
    fclose(fid);
    unix(['mv ' contfile ' ' fullfile(rootdir,'oldContents.m~')]);
    moved=1;
  end
  
  lines{end+1} = AutoString;
  
  a = help(rootdir);
  hlines = {};
  
  if(length(a))
    newlines = [0 find(a==10)];
    for i=1:length(newlines)-1
      hlines{i}=a(newlines(i)+1:newlines(i+1)-1);
    end
  end
  
  for i=1:length(C)
    hlines{end+1}=' ';
    hlines{end+1}=['  Dir: ',  fullfile(rootdir,C{i}.name)];
    hlines{end+1}=' ';
    for j=1:length(C{i}.cont)
      hlines{end+1}=['  ' C{i}.cont{j}];
    end
  end
  
  
  %now format it
  if( writeit(1) )
    fid = fopen(contfile,'w');
    
    for i=1:length(lines)
      fprintf(fid, '%s\n', lines{i});
    end
    
    fprintf(fid, '%c Created on %s by %s using %s \n','%',datestr(now),...
	    getenv('USER'), mfilename);
    fprintf(fid, '%c \n','%');
    
    
    for i=1:length(hlines)
      fprintf(fid, '%c %s\n', '%', hlines{i});
    end
  
    fclose(fid);
  elseif(moved)
    unix(['mv ' fullfile(rootdir,'oldContents.m~') ' ' contfile]);
  end
  