function out = mapfunc(in, func, otype, varargin)
% mapfunc  map a function onto a array or cell array
%
% out = mapfunc(in, func, otype, func_arguments...)
%
% in - in array or cell array
% func - function handle
% otype - example of output type ({} or []) (def. "in")
%
% out - type otype and contains the result of func applied to each 
% element of in
  
  if(nargin<3)
    otype = in;
  end
  
  if(iscell(in))
    if(iscell(otype))
      for i=1:length(in)
	out{i} = feval(func, in{i}, varargin{:});
      end
    else
      for i=1:length(in)
	out(:,:,i) = feval(func, in{i}, varargin{:});
      end      
      out = squeeze(out);
    end
  else
    if(iscell(otype))
      for i=1:length(in)
	out{i} = feval(func, in(i), varargin{:});
      end
    else
      for i=1:length(in)
	out(:,:,i) = feval(func, in(i), varargin{:});
      end      
      out = squeeze(out);
    end    
  end