% README file for the Portable pixelmap utilities.
% 27 May 1998
%
% Description
% ===========
%
% This is a collection of programs for reading and writing PPM (portable
% pixelmap), PGM (portable graymap), PBM (portable bitmap) and XBM (X11
% bitmap) image files. Ascii/plain encoding and binary/raw encoding is
% supported for both reading and writing. User-specified maximum
% color-component value is supported.
%
% Robustness
% ==========
%
% The functions reading PPM/PGM/PBM images are more robust than ever.
% Comments in the pixel area of ascii encoded PNM images are allowed and
% any garbage (characters other than digits and whitespace) is ignored.
% Also, the functions scan the whole file if necessary in search for a
% PNM magic number. As a consequence, the functions can read the example
% images directly out of the formatted UNIX manual pages pbm(5), pgm(5)
% and ppm(5)!
%
% The function reading XBM images may in rare cases be confused since
% the handling of C comments is not yet good enough.
%
% Installing
% ==========
%
% Once the archive file is unpacked, a subdirectory called pnm is
% created. To make the PNM Toolbox available allways, add the directory
% to the Matlab path by editing the global path initialization file
% pathdef.m or by using the addpath function in the personal
% initialization file startup.m.
%
% Tips
% ====
%
% Binary encoded images are written and read much faster than ascii
% encoded images and are much smaller. However, they are also less
% general and less portable.
%
% Use IM2IND to convert any image to an indexed image with a color map
% tha contains only the colors actually used in the image and only one
% copy of each (duplicate colors and unused colors are removed).
%
% Limitations
% ===========
%
% * Binary encoded PPM and PGM images can not have a maximum pixel value
%   less than 255.
% * User-specified comments are not supported.
% * 3D image matrices and the new datatypes introduced in Matlab 5 are
%   not yet suported.
%
% Things to do
% ============
%
% * Remove the limitations mentioned above.
% * Make toolbox more compatible with the image files in matlab/iofun.
% * Speed up the writing of ascii (plain) PPM/PGM images.
% * Better handling of C comments in XBM images.
%
% Versions and platforms
% ======================
%
% The PNM toolbox requires Matlab 5. It has been tested and seems to run
% without problems on the following versions and platforms:
%
%   5.2.0.3084 on Linux 2.0.33
%   5.1.0.421  on IRIX 6.2
%   5.1.0.421  on Windows95
%
% Home Page
% =========
%
% The home page of the PNM Toolbox on the World Wide Web is
% http://www.math.uio.no/~jacklam/matlab/pnm/index.html
%
% Author
% ======
%
% Comments, suggestions, questions, and bug reports are welcome. Please
% note, however, that I work on these programs on my spare time, so be
% patient.
%
% Author:      Peter J. Acklam
% Time-stamp:  1998-05-27 21:56:27
% E-mail:      jacklam@math.uio.no (Internet)
% URL:         http://www.math.uio.no/~jacklam
