function lh = addLegend(h, str, varargin)
% addLegend   add a legend item to the current plot for the given dawing object 
%
% lh = addLegend(h, str, pos)
% 
% h - a handle to the drawing object (e.g. h = plot(...))
% str - the string for the legend
% pos - (o) "pos" argument to matlab's legend  
%
% lh - legend handle
%
% h can be a vector, and str a cell array of strings of the same length
%
% Example:
%   h = plot([1 2 3],'r'); addLegend(h, 'foo');
%   hold on; 
%   h = plot([2 1 3],'g'); addLegend(h, 'bar');
  
  lh=legend; % get legend handle
  if(length(lh))
    % get previous legends
    ls = get(lh,'UserData');

    % cat these new ones at the end
    if(isstr(str)), str = {str}; end
    strs = {ls.lstrings{:}, str{:}};
    hs = [ls.handles; makecol(h)];
    
    % make new legend
    lh = legend(hs, strs, varargin{:});
    
  else 
    
    %this will be a new legend
    lh = legend(h, str,varargin{:});
  
  end
  
  