function makeHTMLPage(filename, titlestr, imnames, pre_post_text)
% makeHTMLPage   make an HTML page with all the given images 
%
% makeHTMLPage(filename, titlestr, imnames, pre_post_text)
% filename      - name of html page filename (e.g. 'index.html')
% titlestr      - string to use for page title
% imnames       - 2-D cell array of strings
% pre_post_text - (o) additional html formatted text to place before and after table.
%                cell array of length 2 of strings: 
%                {'<h1> html text written before table </h1>', 'post table text'}
%                default: {'',''}
%
% If an "image name" string contains a space charachter, then the string
% is printed in the block instead of being interpreted as an image name. 
% This allows you to place annotations in some cells instead of images. 
%
% Hint: if you want to use this to show dumps of matlab figures, use the 
% function mprint.
  
  if(nargin<4)
    pre_post_text={'',''};
  end
  s = size(imnames);
  fp = fopen(filename,'w');
  fprintf(fp,'<html>\n');
  fprintf(fp,'<head>\n');
  fprintf(fp,'<title>%s</title>\n',titlestr);
  fprintf(fp,'</head>\n');
  fprintf(fp,'<body>\n');
  fprintf(fp,pre_post_text{1});
  fprintf(fp,'<p><table cellpadding=5 border=1>\n');
  for i=1:s(1)
    if(length(imnames{i,1})>1)
      fprintf(fp,'<tr>\n');
      for j=1:s(2)
	if(length(imnames{i,j})>1 & ~any(imnames{i,j}==' '))
	  fprintf(fp,'<td align=center><img src="%s" alt="%s"></td>\n', ...
		  imnames{i,j},imnames{i,j});
	else
	  fprintf(fp,'<td align=left> %s </td>\n', imnames{i,j});
	end
      end
      fprintf(fp,'</tr>\n');
    end
  end
  fprintf(fp,'</table>\n');
  fprintf(fp,pre_post_text{2});
  fprintf(fp,'</body>\n');
  
  
