function [figp] = parseFignum(fignum, minnum)
% [figp] = parseFignum(fignum, minnum)
% deal with fignum arguments that have one of the following
% structures:
% a) [figureNumber] call figure(figureNumber);
% b) [n m start] will call subplot(n,m,start) and return it in figp
% c) [n m start figureNumber] does both of the above
% 
% if form (a) is used, or if n*m<minnum, then this function
% will compute a resonable (close to square) aragement of minnum
% subplots. 
%
% example use:
%  if(exist('fignum')~=1)
%    fignum = 99;
%  end
%  [figp] = parseFignum(fignum, n);
%  for f=1:n
%    subplot(figp(1),figp(2),figp(3)-1+f);
%    imagesc(im{n});
%  end
%  
  
  if(nargin<2)
    minnum = 1;
  end
  figp = [ceil(minnum/ceil(sqrt(minnum))) ceil(sqrt(minnum)) 1];

  if(length(fignum)==3)
    fign=-1;
    figp = fignum; 
  elseif(length(fignum)==4)
    fign=fignum(4);
    if(fignum(1)*fignum(2)>=minnum)
      figp = fignum(1:3);     
    end
  else 
    fign=fignum(1);
  end
  
  if(fign>0)
    figure(fign);
  elseif(fign<0)
    figure;
  end
  
  subplot(figp(1), figp(2), figp(3));  
