function plotLabeled(x, y, pttype, labels, color, offset, varargin)
% plotLabeled   plot points with labels
%
% plotLabeled(x, y, pttype, labels, color, offset, plot_params...)
%
% x,y, pttype - coordinates, line type (see plot)
%               if pttype==[], points are not plotted, just labled
% labels - numeric array or cell string array of lables for points
% color - label color (see letter2color) (def. red)
% offset - (o) [dx, dy] offset of text from coordinate (def. 0)
% plot_params... - additional parameters passed to plot
  
  
  if(length(pttype))
    plot(x,y,pttype, varargin{:});
  end
  
  ish = ishold;
  hold on;
  if(size(x,2)==1)
    x=x';
  end
  if(size(y,2)==1)
    y=y';
  end
  
  if(~exist('color'))
    color=[1 0 0];
  else
    color = letter2color(color);
  end
  
  if(~exist('offset'))
    offset=0;
  end
  if(nargin>3 & length(labels)>0)
    if(isnumeric(labels))
      for i=1:min( length(labels), size(x,1));
	for j=1:size(x,2);
	  text(x(i,j)+offset(1), y(i,j)+offset(end), [' ' num2str(labels(j))], 'Color', color);
	end
      end
    else
      for i=1:min( length(labels), length(x(:)));
	text(x(i)+offset(1), y(i)+offset(end), [' ' labels{i}], 'Color', color);
      end
    end
  else
    for i=1:size(x,1);
      for j=1:size(x,2);
	text(x(i,j)+offset(1), y(i,j)+offset(end), [' ' num2str(j)], 'Color', color);
      end
    end
  end

  if(~ish)
    hold off;
  end
