function hf = hf_compAll(pyr, p, hfdat, para)
% hf_compAll   computes hyper-features for each patch including selected 
%
% hf = hf_compAll(pyr, p, hfdat, para)
%
% hf is a struct with fields:
% 
%   .base = the hyper-features as extraced from patch (not normalized)
%
%   .s = hyper-features that were selected from enlarged list for estimating
%   same/diff dist parameters (enlarged list = raw+der + higher order terms)
%
%   .pair = hyper-features selected for estimating the pairwise correlation
%   parameter (rho)
%
% each of the above is a struct where each field is a hyper-feature, such
% that
%     hf.base.Dv = n-by-1 vector, where 
%     hf.base.Dv(i) is the Dv value for patch p(i,:)
%  

  ;
  
  % for optimization, we might want to compute things on mpyr
  % that will help us to compute hyper-features - for example, most
  % of our current hyper features can be efficiently computed for 
  % for any patch given appropriate integral images... 
  % TODO: currently not implemented
  % pyr = hf_prep(pyr,para)
  
  % this computes raw & derived features (notice that no learned
  % data from hfdat is used) -- note: this is saved mostly for 
  % debugging reasons: the outside world should probably only use
  % hf.s and hf.pair.
  hf.base = hf_compBase(pyr, p, para);
  
  % normalize the base features using the learned normaliztion 
  % (sigmoid) coefficients
  basenorm = hf_normalize(hf.base, hfdat.normal, para);
  
  % extract the "select" hyper-features from the normalized base set
  % as directed by the learned model in hfdat.sel - note that these
  % can be cross terms (not currently implemented) or powers of
  % the base features
  hf.s = hf_compSelect(basenorm, hfdat.selterms, para);
  
  % similarly, extract the hyper-features that will be used for the 
  % pairwise rho (last parameter of Kibble's dist) computation
  % - here we use the un-normalized version
  hf.pair = hf_compSelect(hf.base, hfdat.pairterms, para);
  


  

  
  
  
  
  
  
