function [hfout, normal] = hf_normalize(hfin, normal, para)
% hf_normalize  normalize hyper-features with sigmoid
%
% [hfout, normal] = hf_normalize(hfin, normal, para)
% 
% normal - an structure array that specifies the normalization for each field
% of hfin. If not given, computed from the values in hfin. 
% 
% Given that we are using th hyper-features in a linear system, outliers are not
% welcome.  This uses a sigmoid function to bound the hyper-feature values.
% When the original values are distributed uniformly, this has a very close to a
% linear effect.  If they are distributed normally, this makes them into uniform
% distribution. The ouput values are scaled to [-1 1].
    
  hfout=hfin;
  if(length(normal)>0)
    % if normaliztion given, compute it from 
    for i=1:length(normal)
      valin = getfield(hfin, normal(i).var); 
      val = 2*sigmoid(valin, normal(i).sigmoid(1), normal(i).sigmoid(2))-1;
      hfout = setfield(hfout, normal(i).var, val); 
    end
  else
    fns = fieldnames(hfin);
    for i=1:length(fns)
      normal(i).var = fns{i};
      valin = getfield(hfin, normal(i).var);
      m = mean(valin);
      s = std(valin);
      normal(i).sigmoid=[m s];
      val = 2*sigmoid(valin, normal(i).sigmoid(1), normal(i).sigmoid(2))-1;
      hfout = setfield(hfout, normal(i).var, val); 
    end
  end    
