function selterms = hf_select(hfall, terms, da, para)
% hf_select   this uses LARS to select hyper-features 
%
% selterms = hf_select(hfall, terms, da, para)
%
% hfall - expanded list of hyper-features
% terms - struct array of descriptors of each of the componenets of hfall
% da - appearance distance that the linear model should try to approximate
  
  % make matrix where cols are hyper-features and rows are patches
  C = struct2cell(hfall);
  X = cat(2, C{:});
  % add a bit of jitter to deal with dependent and uniform terms
  X = X + 0.001*rand(size(X));
  y=da;
  
  %normalize input
  X = dplus(X,-mean(X,1));
  X = dtimes(X,1./sqrt(sum(X.^2,1)));
  y = y-mean(y);
  y = y/norm(y);
  
  % do feature selection - select up to use_n_hfs features 
  % TODO: this should be done using x-validation! 
  B = lars(X,y,para.use_n_hfs);
  
  % find the "on" features
  fid = find(B(:,end));
  
  %find their order:
  [num, ord] = sort(-sum(B(fid,:)~=0,2));
  
  % return selected terms
  selterms = terms(fid(ord));
  

  
  
  