function D = h_estDistributionsFromHF(hf, hid, para)
% h_estDistributionsFromHF  compute same and different distributions from hyper-features
%
% D = h_estDistributionsFromHF(hf, hid, para)
%  
% D = nx4, where each row is [smu sv dmu dv]
  
  C = struct2cell(hf.s);  
  X = cat(2, ones(length(C{1}),1), C{:});
  
  % sanity check to make sure the model was trained for these
  % variables
  assert(length(hid.sglm.vars)==length(fieldnames(hf.s)) & ...
	 all(strcmp(fieldnames(hf.s),hid.sglm.vars)));
  assert(length(hid.dglm.vars)==length(fieldnames(hf.s)) & ...
	 all(strcmp(fieldnames(hf.s),hid.dglm.vars)));
  
  % we use the identity link for both mu and gamma (v)
  smu = max(para.min_mu, X*hid.sglm.mu);
  sv = max(para.min_v, X*hid.sglm.v);

  dmu = max(para.min_mu, X*hid.dglm.mu);
  dv = max(para.min_v, X*hid.dglm.v);
  
  D = [smu sv dmu dv];
  