function mi = mi_gammaMI(m1, v1, m2, v2, fignum, x)
% mi_gammaMI    compute mutual information from 2 gamma distributions
%
% mi = mi_gammaMI(m1, v1, m2, v2, fignum, x)
% or 
% mi = mi_gammaMI(D, fignum, x)
%
% D - n x 4, such that D = [m1, v1, m2, v2];
% m1,..., v2 - are nx1 vectors of gamma distribution 1 & 2 parameters
%  
% fignum - (opt) if not [], the 2 distributions are plotted.
% x - (opt) x samples to use -- if not given, 1000 equally spaced samples 
%     are generated
% 
% see also mi_gammaMIlut.m 
%
% A note on the Gamma distribution:
% In our parameterization, 2 degrees of freedom are 
%    v = gamma and m = mean. 
% Matlab's gampdf can be called with the substitusion b=m/v like this
%    gampdf(v, m/v)  
% Other useful conversions: 
% v = m^2/var;  var = m^2/v;  m = v*b;  b=m/v
  
  
  xgiven=0;
  if(nargin<4)
    if(nargin>1)
      fignum=v1;
    end
    if(nargin>2)
      x=m2;
    end
    DP=m1;
    m1=DP(:,1); v1=DP(:,2); m2=DP(:,3); v2=DP(:,4);
  end

  if(exist('x')~=1)
    xgiven=1;
  end

  show=0;
  if(exist('fignum')==1 & any(fignum))
    if(fignum>0)
      figure(fignum);
    end
    show = 1;
  end
  
  for i=1:length(m1)    
    if(~xgiven)
      x = linspace(m1(i)/1000, m2(i)+4*max(m1(i)/sqrt(v1(i)), ...
					   m2(i)/sqrt(v2(i))), 1000);
    end
    a1 = gampdf(x, v1(i), m1(i)./v1(i));
    a2 = gampdf(x, v2(i), m2(i)./v2(i));
    mi(i,1) = mutinfo([a1/sum(a1)*.5;a2/sum(a2)*.5]);

    if(show)
      mplot(x,a1,'r');
      hold on; 
      mplot(x,a2,'b');
      title(tostring('MI=', mi(i)));
    end
  end 

  if(show)
    hold off; 
  end	  