function [mi] = mi_gammaMIlut(m1, v1, m2, v2, lut)
% mi_gammaMIlut   compute mutual information from 2 gamma distributions with LUT 
%
% [mi] = mi_gammaMIlut(m1, v1, m2, v2, lut)
% or
% [mi] = mi_gammaMIlut(D, lut)
%
% D - n x 4, such that D = [m1, v1, m2, v2];
% m1,..., v2 - are nx1 vectors of gamma distribution 1 & 2 parameters
% 
% lut - (optional) look up table. If not given, last used (persistant) lut
%       is used. If never called, the mat file 
%
  persistent plut;
  
  % check how we were called, and set m1...v2 and optionally 
  % plut if we were given a lut to use. 
  if(nargin<4)
    if(nargin==2)
      plut=v1;
    end
    DP=m1;
    m1=DP(:,1); v1=DP(:,2); m2=DP(:,3); v2=DP(:,4);
  elseif(nargin==5)
    plut=lut;
  end
  
  % if plut is still not set, load it from stored mat file.
  if(length(plut)==0)
    load GamMuInfoLUTmv;
    plut = milut;
  end
  
  % convert to 3-dof lut axis: log(m2/m1), log(v1), log(v2) 
  v1s = max(plut.v1r(1), min(plut.v1r(end), log(v1)));
  m2s = max(plut.m2r(1), min(plut.m2r(end), log(m2./m1)));
  v2s = max(plut.v2r(1), min(plut.v2r(end), log(v2)));
  
  % now do interp
  mi = interp3(plut.m2r, plut.v1r , plut.v2r, plut.mi, m2s, v1s, v2s);
  
  