function m = id_matchPatch(lpyr, rpyr, p, para)
% id_matchPatch   finds the best matching patch for p of lpyr within rpyr
%
% m = id_matchPatch(lpyr, rpyr, p, para)
%
% p is [scale x y sx sy] (scale is in octaves, x,y,rx,ry in lev=0 coords)
% m is [x y da dx dy] (if error, [inf inf inf inf inf])
% para.search_radius is [x_search_r y_search_r]

  ;
  %find pyramid level to use (closest to scale parameter)
  useli = findClosestPyrLevel(lpyr,p(1));
  
  % convert to lev coordinates
  c = round(p(2:3)*2^(-lpyr{useli}.scale));
  r = round(p(4:5)*2^(-lpyr{useli}.scale));
  
  % extract "left" patch
  lpat = id_cropPatch(lpyr{useli}.fim, p, lpyr{useli}.scale);
  lpatsz = size(lpat);
  
  % extract "right" search area
  [rsarea, rsoffset] = id_cropPatch(rpyr{useli}.fim, p, rpyr{useli}.scale, ...
				    para.search_radius);
  
  %make sure we have a large enough search area ( that is, that rsarea extends 
  % at least as far as lpat in all directions)
  poff = rsoffset.*[1 -1 1 -1];
  if(any(poff>0))
    % if not, we have to cut lpat down more 
    lpat = lpat(max(poff(3)+1,1):end-max(poff(4),0), ...
		max(poff(1)+1,1):end-max(poff(2),0), :);
    rsoffset([1 3]) = min(0,rsoffset([1 3]));
    rsoffset([2 4]) = max(0,rsoffset([2 4]));
  end
  
  %compute normalized cross-correlation if there are enough pixels
  % of lpat left
  if(all(size(lpat) >= max(2,lpatsz/3))) 
    C = xcorr2(lpat,rsarea,0,'valid');
  else % set xcorr result to 0
    C=0;
  end
  
  % find best position (max C)
  [da,ind] = max(C(:));
  [y,x] = ind2sub(size(C), ind);
  fp = [x y];

  % compute offset of best location  
  offset = rsoffset([1 3])+fp-1;
  
  %convert offset back to level 0 coords
  offset0 = offset*2^lpyr{useli}.scale;
  
  % return [x y da dx dy], in lev 0 coordinates
  m = [p(2:3)+offset 1-da offset];
  