function p = id_pickCandiatePatches(pyr, para)
% id_pickCandiatePatches  sample a set of candidate patches at multiple scales
%
% p = id_pickCandiatePatches(pyr, para)
%
% para.patch_radius = n x 2 matrix, where each row = [rx ry]. Multiple rows
% define multiple patch sizes. Patch size will be [2*rx+1 2*ry+1].
%
% para.patch_spacing = n x 2 matrix, where each row = [sx sy], where sx,sy
% specifies the distance between the patch centers of the corresponding patch
% size

  if(isfield(pyr{1}, 'pat') & isfield(pyr{1}.pat, 'p') & ...
    pyr{1}.pat.hfbase_tag==para.hfbase_tag)
    p=pyr{1}.pat.p;
    if(para.cache_verbose)
      mdisp('Using Stored Patches for ', pyr{1}.name);
    end
    return;
  end
  
  sz = size1(pyr{1}.im, [1 2]);
  imrect = [1 sz(2) 1 sz(1)]; 
  
  % all patches must fit inside this
  rect = imrect+para.im_margin([1 1 2 2]).*[1 -1 1 -1];

  % patch descriptors [scale posx posy radx rady] all in scale 0 coords
  p=[];
  
  % at each pyramid level
  for lev=1:length(pyr)
    % for each patch size
    for ri=1:size(para.patch_radius,1)
      % convert limit rect to this level
      lrect = rect * 2^-pyr{lev}.scale;
      
      r = para.patch_radius(ri,:);
      s = para.patch_spacing(ri,:);
      
      % find evenly spaced x, y positions     
      x = round(lrect(1)+r(1) : s(1) : lrect(2)-r(1));
      y = round(lrect(3)+r(2) : s(2) : lrect(4)-r(2));
      
      if(length(x) & length(y)) % if we have enough space inside lrect
	% center the samples
	x = x+round((lrect(2)-r(1)-x(end))/2);
	y = y+round((lrect(4)-r(2)-y(end))/2);
	
	% make a grid of them
	[X,Y] = meshgrid(x,y);
	
	%make p, convert to scale 0
	cp = zeros(length(X(:)), 5);
	cp(:, 2:3) = round([X(:) Y(:)] * 2^pyr{lev}.scale);
	cp(:, 1) = pyr{lev}.scale;
	cp(:, 4) = round(r(1) * 2^pyr{lev}.scale);
	cp(:, 5) = round(r(2) * 2^pyr{lev}.scale);
      
	% add into p
	p = [p ; cp];
      end
    end
  end
  

  